summaryrefslogtreecommitdiffstats
path: root/lib/puppet/metatype
diff options
context:
space:
mode:
authorLuke Kanies <luke@madstop.com>2007-12-11 15:35:36 -0600
committerLuke Kanies <luke@madstop.com>2007-12-11 15:35:36 -0600
commitcb0c4eebb0a7b2fadc5e0487e1c692007cb8b2e5 (patch)
treeb4284addea69adf9d19028ff1bab94035b1c1827 /lib/puppet/metatype
parent7ac3bd79621f6c66cd3b5b7041aeba83c27c3602 (diff)
downloadpuppet-cb0c4eebb0a7b2fadc5e0487e1c692007cb8b2e5.tar.gz
puppet-cb0c4eebb0a7b2fadc5e0487e1c692007cb8b2e5.tar.xz
puppet-cb0c4eebb0a7b2fadc5e0487e1c692007cb8b2e5.zip
Renaming 'configuration' to 'catalog', fixing #954.
Diffstat (limited to 'lib/puppet/metatype')
-rw-r--r--lib/puppet/metatype/evaluation.rb2
-rw-r--r--lib/puppet/metatype/instances.rb6
-rw-r--r--lib/puppet/metatype/metaparams.rb10
3 files changed, 9 insertions, 9 deletions
diff --git a/lib/puppet/metatype/evaluation.rb b/lib/puppet/metatype/evaluation.rb
index 0451d50a7..b3b6570b2 100644
--- a/lib/puppet/metatype/evaluation.rb
+++ b/lib/puppet/metatype/evaluation.rb
@@ -32,7 +32,7 @@ class Puppet::Type
# If we're in noop mode, we don't want to store the checked time,
# because it will result in the resource not getting scheduled if
- # someone were to run the configuration in non-noop mode.
+ # someone were to apply the catalog in non-noop mode.
# We're going to go ahead and record that we checked if there were
# no changes, since it's unlikely it will affect the scheduling.
noop = noop?
diff --git a/lib/puppet/metatype/instances.rb b/lib/puppet/metatype/instances.rb
index f6773f0b3..3f44413f8 100644
--- a/lib/puppet/metatype/instances.rb
+++ b/lib/puppet/metatype/instances.rb
@@ -221,8 +221,8 @@ class Puppet::Type
hash.delete :name
end
- if configuration = hash[:configuration]
- hash.delete(:configuration)
+ if catalog = hash[:catalog]
+ hash.delete(:catalog)
end
raise(Puppet::Error, "You must specify a title for objects of type %s" % self.to_s) unless title
@@ -236,7 +236,7 @@ class Puppet::Type
# okay, now make a transobject out of hash
begin
trans = Puppet::TransObject.new(title, self.name.to_s)
- trans.configuration = configuration if configuration
+ trans.catalog = catalog if catalog
hash.each { |param, value|
trans[param] = value
}
diff --git a/lib/puppet/metatype/metaparams.rb b/lib/puppet/metatype/metaparams.rb
index 349a2c1bb..b35adae66 100644
--- a/lib/puppet/metatype/metaparams.rb
+++ b/lib/puppet/metatype/metaparams.rb
@@ -195,12 +195,12 @@ class Puppet::Type
aliases = [aliases]
end
- raise(ArgumentError, "Cannot add aliases without a configuration") unless @resource.configuration
+ raise(ArgumentError, "Cannot add aliases without a catalog") unless @resource.catalog
@resource.info "Adding aliases %s" % aliases.collect { |a| a.inspect }.join(", ")
aliases.each do |other|
- if obj = @resource.configuration.resource(@resource.class.name, other)
+ if obj = @resource.catalog.resource(@resource.class.name, other)
unless obj.object_id == @resource.object_id
self.fail("%s can not create alias %s: object already exists" % [@resource.title, other])
end
@@ -210,8 +210,8 @@ class Puppet::Type
# LAK:FIXME Old-school, add the alias to the class.
@resource.class.alias(other, @resource)
- # Newschool, add it to the configuration.
- @resource.configuration.alias(@resource, other)
+ # Newschool, add it to the catalog.
+ @resource.catalog.alias(@resource, other)
end
end
end
@@ -256,7 +256,7 @@ class Puppet::Type
def validate_relationship
@value.each do |value|
- unless @resource.configuration.resource(*value)
+ unless @resource.catalog.resource(*value)
description = self.class.direction == :in ? "dependency" : "dependent"
raise Puppet::Error, "Could not find #{description} %s[%s]" % [value[0].to_s.capitalize, value[1]]
end